==> libgnome-java-2.10.1.tar.bz2: libgnome-java-2.10.1/src/java/org/gnu/gnome/CanvasRichText.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gnome;
import org.gnu.glib.Handle;
import org.gnu.glib.Type;
/**
 *
 */
public class CanvasRichText extends CanvasItem {

	public CanvasRichText(CanvasGroup group) {
		super(group, gnome_canvas_rich_text_get_type());
	}
	
	/**
	 * Constructs an instance of CanvasRichText from a native widget resource.
	 * @param handle The handle to the native widget.
	 */
	CanvasRichText(Handle handle) {
		super(handle);
	}

	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gnome_canvas_rich_text_get_type());
	}


	native static final protected int gnome_canvas_rich_text_get_type();
	native static final protected void gnome_canvas_rich_text_cut_clipboard(Handle text);
	native static final protected void gnome_canvas_rich_text_copy_clipboard(Handle text);
	native static final protected void gnome_canvas_rich_text_paste_clipboard(Handle text);
	native static final protected void gnome_canvas_rich_text_set_buffer(Handle text, Handle buffer);
	native static final protected Handle gnome_canvas_rich_text_get_buffer(Handle text);
	native static final protected void gnome_canvas_rich_text_get_iter_location(Handle text, Handle iter, Handle location);
	native static final protected void gnome_canvas_rich_text_get_iter_at_location(Handle text, Handle iter, int x, int y);

}

==> libgnome-java-2.11.4.tar.bz2: libgnome-java-2.11.4/src/java/org/gnu/gnome/CanvasRichText.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gnome;

import org.gnu.glib.Type;
import org.gnu.javagnome.Handle;

/**
 *
 */
public class CanvasRichText extends CanvasItem {

	public CanvasRichText(CanvasGroup group) {
		super(group, gnome_canvas_rich_text_get_type());
	}
	
	/**
	 * Constructs an instance of CanvasRichText from a native widget resource.
	 * @param handle The handle to the native widget.
	 */
	CanvasRichText(Handle handle) {
		super(handle);
	}

	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gnome_canvas_rich_text_get_type());
	}


	native static final protected int gnome_canvas_rich_text_get_type();
	native static final protected void gnome_canvas_rich_text_cut_clipboard(Handle text);
	native static final protected void gnome_canvas_rich_text_copy_clipboard(Handle text);
	native static final protected void gnome_canvas_rich_text_paste_clipboard(Handle text);
	native static final protected void gnome_canvas_rich_text_set_buffer(Handle text, Handle buffer);
	native static final protected Handle gnome_canvas_rich_text_get_buffer(Handle text);
	native static final protected void gnome_canvas_rich_text_get_iter_location(Handle text, Handle iter, Handle location);
	native static final protected void gnome_canvas_rich_text_get_iter_at_location(Handle text, Handle iter, int x, int y);

}
